<?php
/**
 * @version     mod_scorpion_sponsors_helper.php - 18/04/2025
 * @copyright   Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
 * @email       info@ScorpionComputers.nl
 */

defined('_JEXEC') or die;

use Joomla\CMS\Log\Log;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

class ScorpionSponsorsHelper
{
    private $moduleNameTech = 'mod_scorpion_sponsors';
    private $moduleNameFull = 'Scorpion Sponsors';
    private $params;
    private $document;
	private $baseURL;
    private $moduleID;
    private $sortorder;
    private $sponsorData = [];
    public $chosenTemplate;

    // Adding some default values to the variables
	public function __construct($params, $id) {
        $this->params           = $params;
        $this->moduleID         = $id;
		$this->baseURL          = Uri::root(true);
		$this->document         = Factory::getDocument();
        $this->sortorder        = $params->get('sortorder', 0);
        $this->sponsorData      = $params->get('sponsors');
        $this->chosenTemplate   = $params->get('template', 'default');
	}

    /**
     * Get the list of sponsors from module parameters.
     * @return  array  An array of sponsor objects.
     */
    public function getSponsors()
    {
        $sponsorsOutput = [];

        foreach ($this->sponsorData as $data) {
            // And check if the sponsor is published
            if (is_object($data) && isset($data->published) && (int) $data->published === 1) {
                // Basic validation/sanitization added here
                // Ensure we have an object with the expected properties
                if (is_object($data) 
                    && isset($data->sponsor_logo, $data->sponsor_name, $data->sponsor_link) 
                ) {
                    // Ensure the link is a valid URL, prepend https if missing schema but looks like a domain
                    if (!empty($data->sponsor_link) && !preg_match('~^(?:f|ht)tps?://~i', $data->sponsor_link)) {
                        if (strpos($data->sponsor_link, '.') !== false && strpos($data->sponsor_link, '@') === false && strpos($data->sponsor_link, ' ') === false) {
                                $data->sponsor_link = 'https://' . $data->sponsor_link;
                            }
                        }
                    }
                // Ensure the name is not empty if there is a link
                if(!empty($data->sponsor_link) && strlen(trim($data->sponsor_name)) == 0) {
                    $data->sponsor_name = $data->sponsor_link;
                }

                $imageSrc = '';
                if (!empty($data->sponsor_logo)) {
                    $imageSrc = Uri::root() . $data->sponsor_logo;
                }
                
                $isLinkValid = filter_var($data->sponsor_link, FILTER_VALIDATE_URL);

                $sponsorsOutput[] = (object) [
                    'logo' => trim($data->sponsor_logo),
                    'imageSrc' => htmlspecialchars(trim($imageSrc), ENT_QUOTES, 'UTF-8'),
                    'name' => htmlspecialchars(trim($data->sponsor_name), ENT_QUOTES, 'UTF-8'),
                    'link' => htmlspecialchars(trim($data->sponsor_link), ENT_QUOTES, 'UTF-8'),
                    'isLinkValid' => $isLinkValid,
                ];
            }
        }

        // Randomize the order of sponsors if needed
        if ($this->sortorder == 0) {
            shuffle($sponsorsOutput);
        }

        return $sponsorsOutput;
    }

	// Add the basic CSS file from this module
	public function addBasicCSS() {
		$urlCSS = $this->baseURL.'/modules/mod_scorpion_sponsors/mod_scorpion_sponsors.css';
		$this->document->addStyleSheet($urlCSS);
		// Add the specific CSS file for this template
		$templateCSS = $this->baseURL.'/modules/mod_scorpion_sponsors/tmpl/'.$this->chosenTemplate.'.css';
		$this->document->addStylesheet($templateCSS);
	}

    // Getting the parameter values for use in the rest of the module
	public function addExtraCSS(&$extraStyle) 
	{
		// Adding style tag to the top of the HTML document for better support by browsers
		$stylelink = '<style>'."\r\n";
		$stylelink .= '/* Styling for '.$this->moduleNameFull.' */'."\r\n";
		$stylelink .= $extraStyle."\r\n";
		$stylelink .= '</style>';
		$this->document->addCustomTag($stylelink);
	}
    
    // Add the extra script to the document
	public function addExtraScript(&$extraScript)
	{
        $extraScript = '/* Extra Javascript for '.$this->moduleNameFull.' */'."\r\n".$extraScript;
		$this->document->addScriptDeclaration($extraScript);
	}

    // Add the slider assets
	public function addSliderAssets() {
		$this->document->addStyleSheet($this->baseURL.'/modules/mod_scorpion_sponsors/tmpl/slider.css');
		$this->document->addStyleSheet('https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css');
		$this->document->addScript('https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js', ['defer' => true], ['type' => 'text/javascript'], ['async' => true]); 
		$this->document->addScript($this->baseURL.'/modules/mod_scorpion_sponsors/tmpl/slider.js', ['defer' => true], ['type' => 'text/javascript'], ['async' => true]); 

	}
} 